<?php
//////////////////////////////////////////////////////////////////////////////////
//                         copyright (c) Arfooo Annuaire                          //
//                    by Hocine Guillaume (c) 2007 - 2008                        //
//                           http://www.arfooo.com/                              //
//    Licence Creative Commons http://creativecommons.org/licenses/by/2.0/fr/   //
//////////////////////////////////////////////////////////////////////////////////

class RssController extends Controller
{
    /**
    * Add sites items to site rss xml object
    */
    function appendSites($channelNode, $sites)
    {
        foreach($sites as $siteRecord)
        {
            $site = $siteRecord->toArray();
            $siteId = $site['siteId'];
            $rawSiteTitle = $site['siteTitle'];

            $site = array_map("utf8_htmlspecialchars", $site);  //must be two times for xml and for injections
            $site = array_map("utf8_htmlspecialchars", $site);

            $encodedSiteTitle = FrontController::changeFr($rawSiteTitle);

            $item = new XmlElement("item");
            $channelNode->appendChild($item);

            // Site's permanent link
            $sitePermaLink = Config::get('siteRootUrl') . FrontController::getRewrittedUrl('/site/details/' . $siteId . '/' . str_replace("/", " ", $rawSiteTitle), false);

            $item->addProperty('title', htmlspecialchars($rawSiteTitle));
            $item->addProperty('link', $sitePermaLink);
            $item->addProperty('description', $site['description']);

            // from mysql - YYYY-MM-DD
            $pubDate = $site['creationDate'];
            $year = substr($pubDate, 0, 4);
            $month = substr($pubDate, 5, 2);
            $day = substr($pubDate, 8, 2);

            // must be for RSS in format: Wed, 15 Aug 2007 08:15:32 +0300
            $pubDate = date('D, j M Y H:i:s O', mktime(0, 0, 0, $month, $day, $year));
            $item->addProperty('pubDate', $pubDate);

            $item->addProperty('guid', $sitePermaLink);

        }
    }

    /**
    * Generate news RSS
    */
    function newsAction()
    {
        $doc = new XmlGenerator();

        $rssNode = $doc->createElement('rss');
        $doc->appendChild($rssNode);

        $rssNode->setAttribute('version', '2.0');

        $channelNode = new XmlElement('channel');
        $rssNode->appendChild($channelNode);

        // add channel properties  //new DOMElement('
        $channelNode->addProperty('title', _t('News'));
        $channelNode->addProperty('link', Config::get('siteRootUrl') . FrontController::getRewrittedUrl('/site/news', false));
        $channelNode->addProperty('description', _t('The new sites'));
        $channelNode->addProperty('language', 'fr-fr');
        $channelNode->addProperty('lastBuildDate', date('D, j M Y H:i:s O'));
        $channelNode->addProperty('generator', 'RSS Generator');

        $sites = $this->site->getNewValidatedSites();
        $this->appendSites($channelNode, $sites);

        $this->set("doc", $doc);
        $this->viewClass = "XmlView";
    }

    /**
    * Generate RSS for specified category
    */
    function categoryAction($categoryId)
    {
        //get category data
        $category = $this->category->findByPk($categoryId);
        if(empty($category))
        {
            return $this->return404();
        }

        $category = $category->toArray();

        $rawCategoryName = $category['name'];

        $doc = new XmlGenerator();

        $rssNode = $doc->createElement('rss');
        $doc->appendChild($rssNode);

        $rssNode->setAttribute('version', '2.0');

        $channelNode = new XmlElement('channel');
        $rssNode->appendChild($channelNode);

        //add channel properties
        $channelNode->addProperty('title', htmlspecialchars($rawCategoryName));
        $channelNode->addProperty('link',  Config::get('siteRootUrl') . FrontController::getRewrittedUrl('/site/category/'.$categoryId.'/'.str_replace("/", " ", $rawCategoryName).'/1', false));

        $channelNode->addProperty('description', _t('Category') . ' ' . htmlspecialchars($rawCategoryName));
        $channelNode->addProperty('language', 'fr-fr');
        $channelNode->addProperty('lastBuildDate', date('D, j M Y H:i:s O'));
        $channelNode->addProperty('generator', 'RSS Generator');

        //retrieve validated sites in this category
        $sites = $this->site->getValidatedSitesInCategory($categoryId);
        $this->appendSites($channelNode, $sites);

        $this->set("doc", $doc);
        $this->viewClass = "XmlView";

    }

    /**
    * Generate RSS for specified site
    */
    function siteAction($siteId)
    {
        //get category data
        $site = $this->site->findByPk($siteId);
        if(empty($site))
        {
            return $this->return404();
        }

        $rawSiteTitle = $site['siteTitle'];

        $doc = new XmlGenerator();

        $rssNode = $doc->createElement('rss');
        $doc->appendChild($rssNode);

        $rssNode->setAttribute('version', '2.0');

        $channelNode = new XmlElement('channel');
        $rssNode->appendChild($channelNode);

        //add channel properties
        $channelNode->addProperty('title', htmlspecialchars($rawSiteTitle));
        $channelNode->addProperty('link',  Config::get('siteRootUrl') . FrontController::getRewrittedUrl('/site/details/'.$siteId.'/'.str_replace("/", " ", $rawSiteTitle), false));

        $channelNode->addProperty('description', _t('Site') . ' ' . htmlspecialchars($rawSiteTitle));
        $channelNode->addProperty('language', 'fr-fr');
        $channelNode->addProperty('lastBuildDate', date('D, j M Y H:i:s O'));
        $channelNode->addProperty('generator', 'RSS Generator');

        $sites = array($site);
        $this->appendSites($channelNode, $sites);

        $this->set("doc", $doc);
        $this->viewClass = "XmlView";

    }
}

?>