<?php
//////////////////////////////////////////////////////////////////////////////////
//    					 copyright (c) Arfooo Annuaire                          //
//   				 by Hocine Guillaume (c) 2007 - 2008                        //
//       					http://www.arfooo.com/                              //
//    Licence Creative Commons http://creativecommons.org/licenses/by/2.0/fr/   //
//////////////////////////////////////////////////////////////////////////////////

class CommentModel extends Model
{   
    protected $primaryKey = "commentId";
    
    function insert($data)
    {
        parent::insert($data);
        $siteId = $data['siteId'];
        $this->updateSiteCommentsCount($siteId);
    }
    
    function update($data, $c)
    {
        parent::update($data, $c);
        
        $comment = $this->find($c);
        $siteId = $comment->siteId;

        $this->updateSiteCommentsCount($siteId);
    }
    
    function del($c, $updateStats = true)
    {
        parent::del($c);
        $condition = $c->getCondition("siteId");
        
        if($updateStats)
        {
            $this->updateSiteCommentsCount($condition['value']);
        }   
    }
    
    function updateSiteCommentsCount($siteId)
    {
        $c = new Criteria();
        $c->add("siteId", $siteId);
        $c->add("validated", "1");
        $commentsCount = $this->getCount($c);
        $this->site->updateByPk(array("commentsCount" => $commentsCount), $siteId);
    }
    
    function getSiteValidatedComments($siteId)
    {
        $c = new Criteria();
        $c->add("siteId", $siteId);
        $c->add("validated", "1");
        
        return $this->comment->findAll($c);
    }
    
    function getCookieName($siteId)
    {
        return md5('siteComment' . $siteId);
    }
    
    function checkCanVote($siteId, $ip)
    {
        $cookieName = $this->getCookieName($siteId);
        
        //if user is banned
        if($this->bannedIp->isBanned($ip))
            return 'You are not allowed to post comments.';
            
        //if have commenting today
        if(isset($_COOKIE[$cookieName]) && $_COOKIE[$cookieName] == date('d.m.Y'))
            return 'You have already commented this site today.';

        return '';    
    }
    
    function setSiteCookie($siteId)
    {
        $urlParts = parse_url(Config::get("siteRootUrl"));
        $path = $urlParts['path'];
        
        setcookie(
                    $this->getCookieName($siteId), 
                    date('d.m.Y'), 
                    mktime ( 0, 0, 0, date('n'), date('j'), date('Y')) + 60 * 60 * 24, $path);
    } 
}

class CommentRecord extends ModelRecord
{
    
}

?>